##  Setting Up Authentication
For SAP LeanIX to communicate with your Collibra instance, you need to set up credentials.
The integration supports the following authentication types:
  * Basic Auth: Enter the credentials of a Collibra user. This mode is less secure compared to OAuth 2.0.
  * OAuth 2.0: Authenticate with your IdP (Identity Provider) and use the bearer token issued by your IdP to communicate with Collibra. This is the recommended and more secure authentication mode.
